@@ -9,6 +9,7 @@ from fast_tracker import Layer, ComponentType
 from fast_tracker.trace import tags
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
+from fast_tracker.utils import functions
 
 
 def install():
@@ -32,9 +33,7 @@ def install():
             parameter = ",".join([str(arg) for arg in args]) if args else ''
             span.tag(Tag(key=tags.DbSqlParameters, val='[' + parameter + ']'))
 
-            print('#######mysql_span_output_start######')
-            print(span)
-            print('#######mysql_span_output_end######')
+            functions.log("mysql span is: %r", span)
 
             return res
 
